# Minimal makefile for Sphinx documentation
#

# You can set these variables from the command line.
SPHINXBUILD      = sphinx-build
SOURCEDIR        = .
BUILDDIR         = _build
LANGUAGE         = en
ROOT_URL        ?= file://$(shell pwd)/$(BUILDDIR)/html
# version/platform convention branch name should be <PLATFORM>/<version>
# Example: branch 'desktop/3.0' has PLATFORM=desktop and VERSION=3.0
GIT_BRANCH      ?= $(shell git rev-parse --abbrev-ref HEAD)
PLATFORM        ?= $(shell echo $(GIT_BRANCH) | cut -d'/' -f1)
VERSION         ?= $(shell echo $(GIT_BRANCH) | cut -d'/' -f2)
DEFAULT_VERSION ?= $(shell python3 common/get_globals.py versions $(PLATFORM))
ifeq ("$(PLATFORM)","")
    HTML_BASEURL    ?= $(ROOT_URL)
else
    HTML_BASEURL    ?= $(ROOT_URL)/$(PLATFORM)
endif
INSTALLDIR      ?= public
SPHINXOPTS      ?= -D language='$(LANGUAGE)' -D release='$(VERSION)' -A platform='$(PLATFORM)' -W --keep-going

# Put it first so that "make" without argument is like "make help".
help:
	@$(SPHINXBUILD) -M help "$(SOURCEDIR)" "$(BUILDDIR)" $(SPHINXOPTS) $(O)

# Create a global redirection for a given PLATFORM to the default VERSION/LANGUAGE of documentation
platform_redirect:
	mkdir -p "$(BUILDDIR)/html/$(PLATFORM)" &&\
	sed 's;REDIRECT;./$(DEFAULT_VERSION)/$(LANGUAGE)/index.html;g' root_template/redirect.html > "$(BUILDDIR)/html/$(PLATFORM)/index.html"

# Create a global redirection for root site to the default LANGUAGE of documentation
root_redirect:
	mkdir -p "$(BUILDDIR)/html" &&\
	sed 's;REDIRECT;./$(LANGUAGE)/index.html;g' root_template/redirect.html > "$(BUILDDIR)/html/index.html"

# Create a redirection to the default LANGUAGE version of the documentation
versioned_redirect:
	mkdir -p "$(BUILDDIR)/html/$(PLATFORM)/$(VERSION)" &&\
	sed 's;REDIRECT;./$(LANGUAGE)/index.html;g' root_template/redirect.html > "$(BUILDDIR)/html/$(PLATFORM)/$(VERSION)/index.html"

versioned_localized_html:
	@$(SPHINXBUILD) -M html "$(SOURCEDIR)" "$(BUILDDIR)/$(PLATFORM)/$(VERSION)/$(LANGUAGE)" \
		$(SPHINXOPTS) \
	        -D html_baseurl='$(HTML_BASEURL)' \
		-A html_baseurl='$(HTML_BASEURL)' &&\
	mkdir -p "$(BUILDDIR)/html/$(PLATFORM)/$(VERSION)" &&\
	rm -rf "$(BUILDDIR)/html/$(PLATFORM)/$(VERSION)/$(LANGUAGE)" &&\
	mv "$(BUILDDIR)/$(PLATFORM)/$(VERSION)/$(LANGUAGE)/html" "$(BUILDDIR)/html/$(PLATFORM)/$(VERSION)/$(LANGUAGE)" &&\
	echo "Build is located in $(BUILDDIR)/html/$(PLATFORM)/$(VERSION)/$(LANGUAGE)"

install:
	test -d $(BUILDDIR)/html &&\
	mkdir -p $(INSTALLDIR) &&\
	rsync -av $(BUILDDIR)/html/* $(INSTALLDIR)/

clean_install:
	rm -rf $(INSTALLDIR)

update_common:
	git submodule update --remote --rebase

html: versioned_localized_html

# Catch-all target: route all unknown targets to Sphinx using the new
# "make mode" option.  $(O) is meant as a shortcut for $(SPHINXOPTS).
%:
	@$(SPHINXBUILD) -M $@ "$(SOURCEDIR)" "$(BUILDDIR)" $(SPHINXOPTS) $(O)

.PHONY: help platform_redirect root_redirect versioned_redirect versioned_localized_html install clean_install update_common html
